Replace cvmx_usb_isochronous_flags_t with enum cvmx_usb_isochronous_flags.

Signed-off-by: Aaro Koskinen <aaro.koski...@iki.fi>
---
 drivers/staging/octeon-usb/cvmx-usb.c |  2 +-
 drivers/staging/octeon-usb/cvmx-usb.h | 18 ++++++++++++------
 2 files changed, 13 insertions(+), 7 deletions(-)

diff --git a/drivers/staging/octeon-usb/cvmx-usb.c 
b/drivers/staging/octeon-usb/cvmx-usb.c
index a77d930..2d9474a 100644
--- a/drivers/staging/octeon-usb/cvmx-usb.c
+++ b/drivers/staging/octeon-usb/cvmx-usb.c
@@ -2291,7 +2291,7 @@ int cvmx_usb_submit_control(cvmx_usb_state_t *state, int 
pipe_handle,
  *                 Number of frames into the future to schedule
  *                 this transaction.
  * @flags:         Flags to control the transfer. See
- *                 cvmx_usb_isochronous_flags_t for the flag
+ *                 enum cvmx_usb_isochronous_flags for the flag
  *                 definitions.
  * @number_packets:
  *                 Number of sequential packets to transfer.
diff --git a/drivers/staging/octeon-usb/cvmx-usb.h 
b/drivers/staging/octeon-usb/cvmx-usb.h
index 6c404b0..cf49b13 100644
--- a/drivers/staging/octeon-usb/cvmx-usb.h
+++ b/drivers/staging/octeon-usb/cvmx-usb.h
@@ -488,13 +488,19 @@ extern int cvmx_usb_submit_control(cvmx_usb_state_t 
*state, int pipe_handle,
                                    void *user_data);
 
 /**
  * Flags to pass the cvmx_usb_submit_isochronous() function.
transfer
+ *                                         is less than the maximum packet size
+ *                                         of the device.
+ * @CVMX_USB_ISOCHRONOUS_FLAGS_ASAP:       Schedule the transaction as soon as
+ *                                         possible.
  */
-typedef enum
-{
-    CVMX_USB_ISOCHRONOUS_FLAGS_ALLOW_SHORT = 1<<0,  /**< Do not return an 
error if a transfer is less than the maximum packet size of the device */
-    CVMX_USB_ISOCHRONOUS_FLAGS_ASAP = 1<<1,         /**< Schedule the 
transaction as soon as possible */
-} cvmx_usb_isochronous_flags_t;
+enum cvmx_usb_isochronous_flags {
+       CVMX_USB_ISOCHRONOUS_FLAGS_ALLOW_SHORT  = 1 << 0,
+       CVMX_USB_ISOCHRONOUS_FLAGS_ASAP         = 1 << 1,
+};
 
 extern int cvmx_usb_submit_isochronous(cvmx_usb_state_t *state, int 
@@ -488,13 +488,19 @@ extern int cvmx_usb_submit_control(cvmx_usb_state_t 
 
 /**
- * Flags to pass the cvmx_usb_submit_isochronous() function.
+ * enum cvmx_usb_isochronous_flags - flags to pass the
+ *                                  cvmx_usb_submit_isochronous() function.
+ *
+ * @CVMX_USB_ISOCHRONOUS_FLAGS_ALLOW_SHORT: Do not return an error if a 
transfer
pipe_handle,
                                        int start_frame, int flags,
-- 
1.8.3.2

_______________________________________________
devel mailing list
de...@linuxdriverproject.org
http://driverdev.linuxdriverproject.org/mailman/listinfo/driverdev-devel

Reply via email to